Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type DeploymentConfigLister ¶
type DeploymentConfigLister interface {
// List lists all DeploymentConfigs in the indexer.
List(selector labels.Selector) (ret []*v1.DeploymentConfig, err error)
// DeploymentConfigs returns an object that can list and get DeploymentConfigs.
DeploymentConfigs(namespace string) DeploymentConfigNamespaceLister
DeploymentConfigListerExpansion
}
DeploymentConfigLister helps list DeploymentConfigs.
func NewDeploymentConfigLister ¶
func NewDeploymentConfigLister(indexer cache.Indexer) DeploymentConfigLister
NewDeploymentConfigLister returns a new DeploymentConfigLister.
type DeploymentConfigListerExpansion ¶
type DeploymentConfigListerExpansion interface{}
DeploymentConfigListerExpansion allows custom methods to be added to DeploymentConfigLister.
type DeploymentConfigNamespaceLister ¶
type DeploymentConfigNamespaceLister interface {
// List lists all DeploymentConfigs in the indexer for a given namespace.
List(selector labels.Selector) (ret []*v1.DeploymentConfig, err error)
// Get retrieves the DeploymentConfig from the indexer for a given namespace and name.
Get(name string) (*v1.DeploymentConfig, error)
DeploymentConfigNamespaceListerExpansion
}
DeploymentConfigNamespaceLister helps list and get DeploymentConfigs.
type DeploymentConfigNamespaceListerExpansion ¶
type DeploymentConfigNamespaceListerExpansion interface{}
DeploymentConfigNamespaceListerExpansion allows custom methods to be added to DeploymentConfigNamespaceLister.
Click to show internal directories.
Click to hide internal directories.